# RegEx Tester

This project will help to have a simple module that will help to test regexes in a simple and structured way.

# INSTALLATION 

pip install regtester

# Usage

regtester folder/file path to execute one or many tests in a folder
every test has to inherit the class RegExTest inside the module

# Test

The module can be tested using the command : regtester-test